VerilogAE helpers
==================

As mentioned multiple times in this documentation DMT relies on `VerilogAE <https://man.sr.ht/~dspom/openvaf_doc/verilogae/>`__ to access information and equations in Verilog-AMS models. This module here collects the necessary helper functions to do this properly:

.. automodule:: DMT.external.verilogae
    :members:
    :undoc-members:
    :show-inheritance: